@@ -14,6 +14,7 @@ from tqdm import tqdm
 from collections import Counter
 download('stopwords')
 
+
 def preprocess(sentence: str, remove_punct: bool, remove_stop_words: bool, stemm: bool, lang: str='en') -> str: 
     if lang.lower() == 'en':
         ps = PorterStemmer()
@@ -92,6 +93,7 @@ class sentence_tranformer_checker():
         targets: Union[List[str], pd.DataFrame], 
         target_group: Union[List[str], pd.DataFrame]=None,
         target_col: str=None, 
+        device: str = None,
         model: SentenceTransformer=None, 
         lang: str='en', 
         only_include: List[str]=None,
@@ -103,17 +105,16 @@ class sentence_tranformer_checker():
     ):    
         """
         parameters:
-            source: dataframe or list of input texts to find closest match for.
-            target: dataframe or list of targets text to compare with.
-            model (optional): a sentence tranformer model object, to use instead of the default one, for more [details](https://www.sbert.net/).
+            targets: dataframe or list of targets text to compare with.
             target_group (optional): goups ids for the target to match only a single target for each group, can either provide list of ids,
             or the column name in the target dataframe.
-            source_col (partially optional): the source column name used to match, *must be specified for dataframe matching*.
             target_col (partially optional): the target column name used to match, *must be specified for dataframe matching*.
+            device: the device to do the encoding on operations in (cpu|cuda),
+            model (optional): a sentence tranformer model object, to use instead of the default one, for more [details](https://www.sbert.net/).
+            lang (optional): the languge of the model ('en'|'ar').
             only_include (optional): used only for dataframe matching, allow providing a list of column names to only include for the target matches, provide empty list to get only target_col.
             encode_batch (optional): the number of sentences to encode in a batch.
             encode_target: boolean flag to indicate whatever to enocde the targets when initilizing the object (to cache target encoding).
-            lang (optional): the languge of the model ('en'|'ar').
             remove_punct: boolean flag to indicate whatever to remove punctuations. 
             remove_stop_words: boolean flag to indicate whatever to remove stop words.
             stemm: boolean flag to indicate whatever to do stemming.
@@ -124,6 +125,7 @@ class sentence_tranformer_checker():
         self.remove_stop_words = remove_stop_words
         self.stemm = stemm
         self.lang = lang 
+        self.device = device.lower()
 
         if isinstance(targets, pd.DataFrame):
             self.use_frames = True
@@ -170,16 +172,17 @@ class sentence_tranformer_checker():
             raise ValueError('Targets contain null values')
 
         self.model = model
+        self.model.device = device
         # if no model is provided use the default model
         if model is None:
             print('initializing the model...')
             if lang.lower() == 'en':
-                self.model = SentenceTransformer('all-MiniLM-L6-v2', device='cuda')
+                self.model = SentenceTransformer('all-MiniLM-L6-v2', device=device)
                 print('done...')
             else:
-                self.model = SentenceTransformer('distiluse-base-multilingual-cased-v1', device='cuda')
+                self.model = SentenceTransformer('distiluse-base-multilingual-cased-v1', device=device)
                 print('done...')
-        
+
         if encode_target:  
             print('enocding targets: ')
             self.encoded_targets = self.model.encode(self.target_names, batch_size=self.encode_batch, show_progress_bar=True,  normalize_embeddings=True) # encode the targets
